=== modified file 'Makefile.am'
--- Makefile.am	2009-12-24 23:55:44 +0000
+++ Makefile.am	2009-12-27 06:31:41 +0000
@@ -52,7 +52,8 @@
 CLEANFILES=		${BUILT_SOURCES}
 DISTCLEANFILES=		ac_available_languages_fragment \
 			.plugin.scan \
-			config/bzr_revinfo
+			config/bzr_revinfo \
+			config/top.h
 
 MAINTAINERCLEANFILES=	autom4te.cache
 

=== modified file 'config/make-lint.py'
--- config/make-lint.py	2009-12-21 03:35:16 +0000
+++ config/make-lint.py	2009-12-27 06:31:41 +0000
@@ -127,6 +127,7 @@
         'sql_yacc', 'gperf', 'drizzled/probes.h',
         'drizzled/function_hash.h', 'drizzled/symbol_hash.h',
         'util/dummy.cc', 'drizzled/sql_yacc.h', 'drizzled/configmake.h',
+	'drizzled/plugin/version.h',
         'drizzled/plugin/load_list.h']:
         if exclude in path:
             return False

=== modified file 'drizzled/atomic/pthread_traits.h'
--- drizzled/atomic/pthread_traits.h	2009-07-27 18:16:18 +0000
+++ drizzled/atomic/pthread_traits.h	2009-12-14 19:51:51 +0000
@@ -31,9 +31,10 @@
   pthread_mutex_t the_mutex;
   bool locked;
 public:
-  mutex_wrapper(void): locked(false)
+  mutex_wrapper(void)
+   : the_mutex(),
+     locked(false)
   {
-    locked= false;
     (void) pthread_mutex_init(&the_mutex,  NULL);
   }
   ~mutex_wrapper(void)

=== modified file 'drizzled/atomics.h'
--- drizzled/atomics.h	2009-08-30 00:26:17 +0000
+++ drizzled/atomics.h	2009-12-14 19:51:51 +0000
@@ -45,6 +45,8 @@
 template<typename I>            // Primary template
 struct atomic_base {
   volatile I my_value;
+  atomic_base() : my_value(0) {}
+  virtual ~atomic_base() {}
 };
 
 template<typename I, typename D, typename T >
@@ -54,6 +56,7 @@
 public:
   typedef I value_type;
 
+  atomic_impl() : atomic_base<I>(), traits() {}
 
   value_type fetch_and_add( D addend )
   {
@@ -97,32 +100,37 @@
   }
 
 public:
-  value_type operator+=( D addend )
+  atomic_impl<I,D,T>& operator+=( D addend )
   {
-      return fetch_and_add(addend)+addend;
+    fetch_and_add(addend)+addend;
+    return *this;
   }
 
-  value_type operator-=( D addend )
+  atomic_impl<I,D,T>& operator-=( D addend )
   {
     // Additive inverse of addend computed using binary minus,
     // instead of unary minus, for sake of avoiding compiler warnings.
     return operator+=(D(0)-addend);
   }
 
-  value_type operator++() {
-    return fetch_and_add(1)+1;
-  }
-
-  value_type operator--() {
-    return fetch_and_add(D(-1))-1;
-  }
-
-  value_type operator++(int) {
-    return fetch_and_add(1);
-  }
-
-  value_type operator--(int) {
-    return fetch_and_add(D(-1));
+  atomic_impl<I,D,T>& operator++() {
+    fetch_and_add(1);
+    return *this;
+  }
+
+  atomic_impl<I,D,T>& operator--() {
+    fetch_and_add(D(-1));
+    return *this;
+  }
+
+  atomic_impl<I,D,T> operator++(int) {
+    fetch_and_add(1);
+    return *this;
+  }
+
+  atomic_impl<I,D,T> operator--(int) {
+    fetch_and_add(D(-1));
+    return *this;
   }
 
 };
@@ -141,7 +149,7 @@
   template<> struct atomic<T>                                           \
   : internal::atomic_impl<T,T,ATOMIC_TRAITS<T,T> > {                    \
     atomic<T>() : internal::atomic_impl<T,T,ATOMIC_TRAITS<T,T> >() {}   \
-    T operator=( T rhs ) { return store_with_release(rhs); }            \
+    atomic<T>& operator=( T rhs ) { store_with_release(rhs); return *this; } \
   };
 /* *INDENT-ON* */
 

=== modified file 'drizzled/sql_string.cc'
--- drizzled/sql_string.cc	2009-12-23 21:16:15 +0000
+++ drizzled/sql_string.cc	2009-12-27 06:31:41 +0000
@@ -32,55 +32,60 @@
 *****************************************************************************/
 
 String::String()
-  : Ptr(0),
+  : Ptr(NULL),
     str_length(0),
     Alloced_length(0),
-    alloced(0),
+    alloced(false),
     str_charset(&my_charset_bin)
 { }
 
+
 String::String(uint32_t length_arg)
-  : Ptr(0),
+  : Ptr(NULL),
     str_length(0),
     Alloced_length(0),
-    alloced(0),
+    alloced(false),
     str_charset(&my_charset_bin)
 {
   (void) real_alloc(length_arg);
 }
 
+
 String::String(const char *str, const CHARSET_INFO * const cs)
-  : Ptr(const_cast<char*>(str)),
+  : Ptr(const_cast<char *>(str)),
     str_length(static_cast<uint32_t>(strlen(str))),
     Alloced_length(0),
-    alloced(0),
+    alloced(false),
     str_charset(cs)
 { }
 
 String::String(const char *str, uint32_t len, const CHARSET_INFO * const cs)
-  : Ptr(const_cast<char*>(str)),
+  : Ptr(const_cast<char *>(str)),
     str_length(len),
     Alloced_length(0),
-    alloced(0),
+    alloced(false),
     str_charset(cs)
 { }
 
-String::String(char *str,uint32_t len, const CHARSET_INFO * const cs)
+
+String::String(char *str, uint32_t len, const CHARSET_INFO * const cs)
   : Ptr(str),
     str_length(len),
     Alloced_length(len),
-    alloced(0),
+    alloced(false),
     str_charset(cs)
 { }
 
+
 String::String(const String &str)
   : Ptr(str.Ptr),
     str_length(str.str_length),
     Alloced_length(str.Alloced_length),
-    alloced(0),
+    alloced(false),
     str_charset(str.str_charset)
 { }
 
+
 void *String::operator new(size_t size, MEM_ROOT *mem_root)
 {
   return alloc_root(mem_root, static_cast<uint32_t>(size));

=== modified file 'drizzled/sql_string.h'
--- drizzled/sql_string.h	2009-12-22 22:13:48 +0000
+++ drizzled/sql_string.h	2009-12-27 06:31:41 +0000
@@ -78,7 +78,7 @@
   static void operator delete(void *, size_t)
   { }
   static void operator delete(void *, MEM_ROOT *)
-  { /* never called */ }
+  { }
   ~String();
 
   inline void set_charset(const CHARSET_INFO * const charset_arg)

